Cookbook
========

Scaling
-------

To double the size of a morphology:

.. code-block:: console

    neuroc scale file --scaling 2.0 input_file output_file

And for all morphologies in a folder:

.. code-block:: console

    neuroc scale folder --scaling 2.0 input_folder output_folder
